@@ -305,11 +305,10 @@ describe 'trove::taskmanager' do
       end
     end
 
-    context 'with amqp rpc' do
+    context 'with amqp messaging' do
       let :pre_condition do
         "class { 'trove' :
-           nova_proxy_admin_pass => 'verysecrete',
-           rpc_backend           => 'amqp' }"
+           nova_proxy_admin_pass => 'verysecrete'}"
       end
 
       it do
